@@ -19,7 +19,7 @@ use Plack::Util::Accessor qw/ default_rate rules cache file _match greylist retr
 use Ref::Util             qw/ is_plain_arrayref /;
 use Time::Seconds         qw/ ONE_MINUTE /;
 
-our $VERSION = 'v0.4.2';
+our $VERSION = 'v0.4.3';
 
 
 sub prepare_app {
@@ -162,7 +162,7 @@ Plack::Middleware::Greylist - throttle requests with different rates based on ne
 
 =head1 VERSION
 
-version v0.4.2
+version v0.4.3
 
 =head1 SYNOPSIS
 
@@ -275,6 +275,19 @@ e.g. one minute.  If you use a different time interval, then you may need to adj
 This does not try and enforce any consistency or block overlapping netblocks.  It trusts L<Net::IP::Match::Trie> to
 handle any overlapping or conflicting network ranges, or to specify exceptions for larger blocks.
 
+When configuring the L</greylist> netblocks from a configuration file using L<Config::General>, duplicate netblocks may
+be merged in unexpected ways, for example
+
+    10.0.0.0/16   60 group-1
+
+    ...
+
+    10.0.0.0/16  120 group-2
+
+may be merged as something like
+
+    '10.0.0.0/16' => [ '60 group-1', '120 group-2' ],
+
 Some search engine robots may not respect HTTP 429 responses, and will treat these as errors. You may want to make an
 exception for trusted networks that gives them a higher rate than the default.
 
